"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildHandler = exports.steps = void 0;
const node_1 = require("@metamask/snaps-utils/node");
const utils_1 = require("@metamask/utils");
const implementation_1 = require("./implementation.cjs");
const utils_2 = require("./utils.cjs");
const errors_1 = require("../../errors.cjs");
const utils_3 = require("../../utils/index.cjs");
exports.steps = [
    {
        name: 'Checking the input file.',
        condition: ({ build: enableBuild }) => enableBuild,
        task: async ({ config }) => {
            const { input } = config;
            if (!(await (0, node_1.isFile)(input))) {
                throw new errors_1.CommandError(`Input file not found: "${input}". Make sure that the "input" field in your Snap config is correct.`);
            }
        },
    },
    {
        name: 'Building the Snap bundle.',
        condition: ({ build: enableBuild }) => enableBuild,
        task: async (context) => {
            const { analyze, config, spinner } = context;
            const compiler = await (0, implementation_1.build)(config, {
                analyze,
                evaluate: config.evaluate,
                spinner,
            });
            if (analyze) {
                return {
                    ...context,
                    port: await (0, utils_2.getBundleAnalyzerPort)(compiler),
                };
            }
            return undefined;
        },
    },
    {
        name: 'Running analyser.',
        condition: ({ analyze }) => analyze,
        task: async ({ spinner, port }) => {
            (0, utils_1.assert)(port, 'Port is not defined.');
            (0, utils_3.success)(`Bundle analyzer running at http://localhost:${port}.`, spinner);
            spinner.stop();
        },
    },
];
/**
 * Build all files in the given source directory to the given destination
 * directory.
 *
 * This creates the destination directory if it doesn't exist.
 *
 * @param config - The config object.
 * @param analyze - Whether to analyze the bundle.
 * @returns Nothing.
 */
async function buildHandler(config, analyze = false) {
    return await (0, utils_3.executeSteps)(exports.steps, {
        build: true,
        config,
        analyze,
    });
}
exports.buildHandler = buildHandler;
//# sourceMappingURL=build.cjs.map