"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.build = void 0;
const webpack_1 = require("../../webpack/index.cjs");
/**
 * Build the snap bundle. This uses Webpack to build the bundle.
 *
 * @param config - The config object.
 * @param options - The Webpack options.
 * @returns A promise that resolves when the bundle is built.
 */
async function build(config, options) {
    const compiler = await (0, webpack_1.getCompiler)(config, options);
    return await new Promise((resolve, reject) => {
        compiler.run((runError) => {
            if (runError) {
                reject(runError);
                return;
            }
            compiler.close((closeError) => {
                if (closeError) {
                    reject(closeError);
                    return;
                }
                resolve(compiler);
            });
        });
    });
}
exports.build = build;
//# sourceMappingURL=implementation.cjs.map