import { getCompiler } from "../../webpack/index.mjs";
/**
 * Build the snap bundle. This uses Webpack to build the bundle.
 *
 * @param config - The config object.
 * @param options - The Webpack options.
 * @returns A promise that resolves when the bundle is built.
 */
export async function build(config, options) {
    const compiler = await getCompiler(config, options);
    return await new Promise((resolve, reject) => {
        compiler.run((runError) => {
            if (runError) {
                reject(runError);
                return;
            }
            compiler.close((closeError) => {
                if (closeError) {
                    reject(closeError);
                    return;
                }
                resolve(compiler);
            });
        });
    });
}
//# sourceMappingURL=implementation.mjs.map