"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBundleAnalyzerPort = void 0;
const webpack_bundle_analyzer_1 = require("webpack-bundle-analyzer");
/**
 * Get the port of the bundle analyzer server.
 *
 * @param compiler - The Webpack compiler.
 * @returns The port of the bundle analyzer server.
 */
async function getBundleAnalyzerPort(compiler) {
    const analyzerPlugin = compiler.options.plugins.find((plugin) => plugin instanceof webpack_bundle_analyzer_1.BundleAnalyzerPlugin);
    if (analyzerPlugin?.server) {
        const { http } = await analyzerPlugin.server;
        const address = http.address();
        if (typeof address === 'string') {
            const { port } = new URL(address);
            return parseInt(port, 10);
        }
        return address?.port;
    }
    return undefined;
}
exports.getBundleAnalyzerPort = getBundleAnalyzerPort;
//# sourceMappingURL=utils.cjs.map