"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.manifestHandler = void 0;
const node_1 = require("@metamask/snaps-utils/node");
const path_1 = require("path");
const implementation_1 = require("./implementation.cjs");
const errors_1 = require("../../errors.cjs");
const utils_1 = require("../../utils/index.cjs");
const eval_1 = require("../eval/index.cjs");
const steps = [
    {
        name: 'Checking the input file.',
        task: async ({ input }) => {
            if (!(await (0, node_1.isFile)(input))) {
                throw new errors_1.CommandError(`Manifest file not found: "${input}". Make sure that the \`snap.manifest.json\` file exists.`);
            }
        },
    },
    {
        name: 'Evaluating the Snap bundle.',
        condition: ({ options }) => options.eval,
        task: async (context) => {
            const { config, spinner } = context;
            const path = (0, path_1.resolve)(process.cwd(), config.output.path, config.output.filename);
            const { exports } = await (0, eval_1.evaluate)(path);
            (0, utils_1.info)(`Snap bundle evaluated successfully.`, spinner);
            return {
                ...context,
                exports,
            };
        },
    },
    {
        name: 'Validating the Snap manifest.',
        task: async ({ input, options, exports, spinner }) => {
            const write = getWriteManifest(options);
            const valid = await (0, implementation_1.manifest)(input, write, exports, spinner);
            if (valid) {
                spinner.succeed('The Snap manifest file is valid.');
            }
        },
    },
];
/**
 * Get whether to write the manifest to disk.
 *
 * @param options - The options object.
 * @returns Whether to write the manifest to disk.
 */
function getWriteManifest(options) {
    if (typeof options.fix === 'boolean') {
        return options.fix;
    }
    return false;
}
/**
 * Validates a snap.manifest.json file. Attempts to fix the manifest and write
 * the fixed version to disk if `writeManifest` is true. Throws if validation
 * fails.
 *
 * @param config - The config object.
 * @param options - The options object.
 */
async function manifestHandler(config, options) {
    await (0, utils_1.executeSteps)(steps, {
        input: config.manifest.path,
        config,
        options,
    });
}
exports.manifestHandler = manifestHandler;
//# sourceMappingURL=manifest.cjs.map