"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sandboxHandler = void 0;
const server_1 = require("./server.cjs");
const utils_1 = require("../../utils/index.cjs");
const build_1 = require("../build/index.cjs");
const steps = [
    ...build_1.steps,
    {
        name: 'Running sandbox.',
        task: async ({ config, spinner }) => {
            const { port } = await (0, server_1.startSandbox)(config);
            (0, utils_1.success)(`Sandbox running at http://localhost:${port}.`, spinner);
            spinner.stop();
        },
    },
];
/**
 * Start the sandbox.
 *
 * @param config - The config object.
 * @param options - The options object.
 * @param options.build - Whether to build the Snap before starting the sandbox.
 */
async function sandboxHandler(config, { build = true }) {
    await (0, utils_1.executeSteps)(steps, {
        analyze: false,
        build,
        config,
    });
}
exports.sandboxHandler = sandboxHandler;
//# sourceMappingURL=sandbox.cjs.map