"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfigByArgv = exports.resolveConfig = exports.loadConfig = exports.getConfig = exports.SnapsConfigStruct = void 0;
const snaps_sdk_1 = require("@metamask/snaps-sdk");
const node_1 = require("@metamask/snaps-utils/node");
const superstruct_1 = require("@metamask/superstruct");
const utils_1 = require("@metamask/utils");
const core_1 = require("@swc/core");
const chalk_1 = require("chalk");
const promises_1 = require("fs/promises");
const module_1 = __importDefault(require("module"));
const path_1 = require("path");
const errors_1 = require("./errors.cjs");
const structs_1 = require("./structs.cjs");
const utils_2 = require("./utils/index.cjs");
const CONFIG_FILES = [utils_2.CONFIG_FILE, utils_2.TS_CONFIG_FILE];
// This struct is essentially the same as the `func` struct, but it's defined
// separately so that we include the function type in the inferred TypeScript
// type definitions.
const SnapsWebpackCustomizeWebpackConfigFunctionStruct = (0, superstruct_1.define)('function', (0, superstruct_1.func)().validator);
exports.SnapsConfigStruct = (0, superstruct_1.object)({
    input: (0, superstruct_1.defaulted)((0, structs_1.file)(), (0, path_1.resolve)(process.cwd(), 'src/index.js')),
    sourceMap: (0, superstruct_1.defaulted)((0, snaps_sdk_1.union)([(0, superstruct_1.boolean)(), (0, snaps_sdk_1.literal)('inline')]), false),
    evaluate: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), true),
    output: (0, superstruct_1.defaulted)((0, superstruct_1.object)({
        path: (0, superstruct_1.defaulted)((0, structs_1.file)(), (0, path_1.resolve)(process.cwd(), 'dist')),
        filename: (0, superstruct_1.defaulted)((0, superstruct_1.string)(), 'bundle.js'),
        clean: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
        minimize: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), true),
    }), {}),
    manifest: (0, superstruct_1.defaulted)((0, superstruct_1.object)({
        path: (0, superstruct_1.defaulted)((0, structs_1.file)(), (0, path_1.resolve)(process.cwd(), 'snap.manifest.json')),
        update: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), true),
    }), {}),
    server: (0, superstruct_1.defaulted)((0, superstruct_1.object)({
        enabled: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), true),
        root: (0, superstruct_1.defaulted)((0, structs_1.file)(), process.cwd()),
        port: (0, superstruct_1.defaulted)((0, superstruct_1.number)(), 8081),
    }), {}),
    environment: (0, superstruct_1.defaulted)((0, superstruct_1.record)((0, superstruct_1.string)(), (0, superstruct_1.unknown)()), {}),
    stats: (0, superstruct_1.defaulted)((0, superstruct_1.object)({
        verbose: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
        builtIns: (0, superstruct_1.defaulted)((0, snaps_sdk_1.union)([
            (0, superstruct_1.object)({ ignore: (0, superstruct_1.defaulted)((0, superstruct_1.array)((0, superstruct_1.string)()), []) }),
            (0, snaps_sdk_1.literal)(false),
        ]), {}),
        buffer: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), true),
    }), {}),
    polyfills: (0, superstruct_1.defaulted)((0, snaps_sdk_1.union)([
        (0, superstruct_1.boolean)(),
        (0, superstruct_1.object)({
            assert: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            buffer: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            console: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            constants: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            crypto: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            domain: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            events: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            http: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            https: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            os: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            path: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            punycode: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            process: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            querystring: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            stream: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            /* eslint-disable @typescript-eslint/naming-convention */
            _stream_duplex: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            _stream_passthrough: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            _stream_readable: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            _stream_transform: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            _stream_writable: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            string_decoder: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            /* eslint-enable @typescript-eslint/naming-convention */
            sys: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            timers: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            tty: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            url: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            util: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            vm: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
            zlib: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
        }),
    ]), false),
    typescript: (0, superstruct_1.defaulted)((0, superstruct_1.object)({
        enabled: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
        configFile: (0, superstruct_1.defaulted)((0, structs_1.file)(), 'tsconfig.json'),
    }), {}),
    features: (0, superstruct_1.defaulted)((0, superstruct_1.object)({
        images: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), true),
    }), {}),
    customizeWebpackConfig: (0, superstruct_1.optional)(SnapsWebpackCustomizeWebpackConfigFunctionStruct),
    experimental: (0, superstruct_1.defaulted)((0, superstruct_1.object)({
        wasm: (0, superstruct_1.defaulted)((0, superstruct_1.boolean)(), false),
    }), {}),
});
/**
 * Get a validated snap config. This validates the config and adds default
 * values for any missing properties.
 *
 * @param config - The config to validate.
 * @returns The validated config.
 */
function getConfig(config) {
    const prefix = 'The snap config file is invalid';
    const suffix = (0, chalk_1.dim)('Refer to the documentation for more information: https://docs.metamask.io/snaps/reference/cli/options/');
    return (0, node_1.createFromStruct)(config, exports.SnapsConfigStruct, prefix, suffix);
}
exports.getConfig = getConfig;
/**
 * Load a snap config from a file. This supports both JavaScript and TypeScript
 * config files, in the CommonJS module format and the ES module format.
 *
 * This assumes that the config file exports a default object, either through
 * `module.exports` or `export default`.
 *
 * @param path - The full path to the config file.
 * @returns The validated config.
 * @throws If the config file is invalid, or if the config file does not have a
 * default export.
 */
async function loadConfig(path) {
    try {
        const contents = await (0, promises_1.readFile)(path, 'utf8');
        const source = await (0, core_1.transform)(contents, {
            swcrc: false,
            jsc: {
                parser: {
                    syntax: 'typescript',
                },
            },
            module: {
                type: 'commonjs',
            },
        });
        const config = new module_1.default(path);
        // @ts-expect-error - This function is not typed.
        config.paths = module_1.default._nodeModulePaths((0, path_1.dirname)(path));
        // @ts-expect-error - This function is not typed.
        config._compile(source.code, path);
        if (!(0, utils_1.hasProperty)(config.exports, 'default')) {
            return getConfig(config.exports);
        }
        return getConfig(config.exports.default);
    }
    catch (error) {
        if (error instanceof node_1.SnapsStructError) {
            throw new errors_1.ConfigError(error.message);
        }
        throw new errors_1.ConfigError(`Unable to load snap config file at "${path}".\n\n${(0, node_1.indent)(error.message)}`);
    }
}
exports.loadConfig = loadConfig;
/**
 * Resolve a snap config. This function will look for a `snap.config.js` or
 * `snap.config.ts` file in the current or specified directory.
 *
 * @param path - The path to resolve the snap config from. Defaults to the
 * current working directory.
 * @returns The resolved and validated snap config.
 * @throws If a snap config could not be found.
 */
async function resolveConfig(path) {
    for (const configFile of CONFIG_FILES) {
        const filePath = (0, path_1.resolve)(path, configFile);
        if (await (0, node_1.isFile)(filePath)) {
            return await loadConfig(filePath);
        }
    }
    throw new errors_1.ConfigError(`Could not find a "snap.config.js" or "snap.config.ts" file in the current or specified directory ("${path}").`);
}
exports.resolveConfig = resolveConfig;
/**
 * Get a snap config from the CLI arguments. This will either load the config
 * from the specified config file, or resolve the config from the current
 * working directory.
 *
 * @param argv - The CLI arguments.
 * @param cwd - The current working directory. Defaults to `process.cwd()`.
 * @returns The resolved and validated snap config.
 */
async function getConfigByArgv(argv, cwd = process.cwd()) {
    if (argv.config) {
        if (!(await (0, node_1.isFile)(argv.config))) {
            throw new errors_1.ConfigError(`Could not find a config file at "${argv.config}". Make sure that the path is correct.`);
        }
        return await loadConfig(argv.config);
    }
    return await resolveConfig(cwd);
}
exports.getConfigByArgv = getConfigByArgv;
//# sourceMappingURL=config.cjs.map