"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.error = exports.info = exports.warn = exports.success = void 0;
const snaps_utils_1 = require("@metamask/snaps-utils");
const chalk_1 = require("chalk");
/**
 * Log a success message. The message is prefixed with a green checkmark.
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
function success(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    (0, snaps_utils_1.logInfo)(`${(0, chalk_1.green)('✔')} ${message}`);
}
exports.success = success;
/**
 * Log a warning message. The message is prefixed with a yellow warning sign.
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
function warn(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    (0, snaps_utils_1.logWarning)(`${(0, chalk_1.yellow)('⚠')} ${message}`);
}
exports.warn = warn;
/**
 * Log an info message.
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
function info(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    (0, snaps_utils_1.logInfo)(`${(0, chalk_1.blue)('ℹ')} ${(0, chalk_1.dim)(message)}`);
}
exports.info = info;
/**
 * Log an error message. The message is prefixed with "Error:".
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
function error(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    (0, snaps_utils_1.logError)(`${(0, chalk_1.red)('✖')} ${message}`);
}
exports.error = error;
//# sourceMappingURL=logging.cjs.map