import { logError, logInfo, logWarning } from "@metamask/snaps-utils";
import $chalk from "chalk";
const { blue, dim, green, red, yellow } = $chalk;
/**
 * Log a success message. The message is prefixed with a green checkmark.
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
export function success(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    logInfo(`${green('✔')} ${message}`);
}
/**
 * Log a warning message. The message is prefixed with a yellow warning sign.
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
export function warn(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    logWarning(`${yellow('⚠')} ${message}`);
}
/**
 * Log an info message.
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
export function info(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    logInfo(`${blue('ℹ')} ${dim(message)}`);
}
/**
 * Log an error message. The message is prefixed with "Error:".
 *
 * @param message - The message to log.
 * @param spinner - The spinner to clear.
 */
export function error(message, spinner) {
    if (spinner) {
        spinner.clear();
        spinner.frame();
    }
    logError(`${red('✖')} ${message}`);
}
//# sourceMappingURL=logging.mjs.map