"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getServer = exports.getAllowedPaths = void 0;
const node_1 = require("@metamask/snaps-utils/node");
const express_1 = __importStar(require("express/index.js"));
const path_1 = require("path");
/**
 * Get the relative path from one path to another.
 *
 * Note: This is a modified version of `path.relative` that uses Posix
 * separators for URL-compatibility.
 *
 * @param from - The path to start from.
 * @param to - The path to end at.
 * @returns The relative path.
 */
function getRelativePath(from, to) {
    return (0, path_1.relative)(from, to).split(path_1.sep).join(path_1.posix.sep);
}
/**
 * Get the allowed paths for the static server. This includes the output file,
 * the manifest file, and any auxiliary/localization files.
 *
 * @param config - The config object.
 * @param manifest - The Snap manifest object.
 * @returns An array of allowed paths.
 */
function getAllowedPaths(config, manifest) {
    const auxiliaryFiles = manifest.source.files?.map((file) => getRelativePath(config.server.root, (0, path_1.resolve)(config.server.root, file))) ?? [];
    const localizationFiles = manifest.source.locales?.map((localization) => getRelativePath(config.server.root, (0, path_1.resolve)(config.server.root, localization))) ?? [];
    const otherFiles = manifest.source.location.npm.iconPath
        ? [
            getRelativePath(config.server.root, (0, path_1.resolve)(config.server.root, manifest.source.location.npm.iconPath)),
        ]
        : [];
    return [
        getRelativePath(config.server.root, (0, path_1.resolve)(config.server.root, config.output.path, config.output.filename)),
        getRelativePath(config.server.root, (0, path_1.resolve)(config.server.root, node_1.NpmSnapFileNames.Manifest)),
        ...auxiliaryFiles,
        ...localizationFiles,
        ...otherFiles,
    ];
}
exports.getAllowedPaths = getAllowedPaths;
/**
 * Get whether the request path is allowed. This is used to check if the request
 * path is in the list of allowed paths for the static server.
 *
 * @param request - The request object.
 * @param config - The config object.
 * @returns A promise that resolves to `true` if the path is allowed, or
 * `false` if it is not.
 */
async function isAllowedPath(request, config) {
    const manifestPath = (0, path_1.join)(config.server.root, node_1.NpmSnapFileNames.Manifest);
    const { result } = await (0, node_1.readJsonFile)(manifestPath);
    const allowedPaths = getAllowedPaths(config, result);
    const path = request.path.slice(1);
    return allowedPaths.some((allowedPath) => path === allowedPath);
}
/**
 * Get a static server for development purposes.
 *
 * Note: We're intentionally not using `webpack-dev-server` here because it
 * adds a lot of extra stuff to the output that we don't need, and it's
 * difficult to customize.
 *
 * @param config - The config object.
 * @param middleware - An array of middleware functions to run before serving
 * the static files.
 * @returns An object with a `listen` method that returns a promise that
 * resolves when the server is listening.
 */
function getServer(config, middleware = []) {
    const app = (0, express_1.default)();
    // Run "middleware" functions before serving the static files.
    middleware.forEach((fn) => fn(app));
    // Check for allowed paths in the request URL.
    app.use((request, response, next) => {
        isAllowedPath(request, config)
            .then((allowed) => {
            if (allowed) {
                // eslint-disable-next-line promise/no-callback-in-promise
                next();
                return;
            }
            response.status(404);
            response.end();
        })
            // eslint-disable-next-line promise/no-callback-in-promise
            .catch(next);
    });
    // Serve the static files.
    app.use((0, express_1.static)(config.server.root, {
        dotfiles: 'deny',
        setHeaders: (res) => {
            res.setHeader('Cache-Control', 'no-cache');
            res.setHeader('Access-Control-Allow-Origin', '*');
        },
    }));
    /**
     * Start the server on the port specified in the config.
     *
     * @param port - The port to listen on.
     * @returns A promise that resolves when the server is listening. The promise
     * resolves to an object with the port and the server instance. Note that if
     * the `config.server.port` is `0`, the OS will choose a random port for us,
     * so we need to get the port from the server after it starts.
     */
    const listen = async (port = config.server.port) => {
        return new Promise((resolve, reject) => {
            // eslint-disable-next-line consistent-return
            const server = app.listen(port, (error) => {
                if (error) {
                    return reject(error);
                }
                const close = async () => {
                    await new Promise((resolveClose, rejectClose) => {
                        server.close((closeError) => {
                            if (closeError) {
                                return rejectClose(closeError);
                            }
                            return resolveClose();
                        });
                    });
                };
                const address = server.address();
                resolve({ port: address.port, server, close });
            });
        });
    };
    return { listen };
}
exports.getServer = getServer;
//# sourceMappingURL=server.cjs.map