/// <reference types="node" />
import type { SnapManifest } from "@metamask/snaps-utils";
import type { Express } from "express/index.js";
import type { Server } from "http";
import type { ProcessedConfig } from "../config.cjs";
/**
 * Get the allowed paths for the static server. This includes the output file,
 * the manifest file, and any auxiliary/localization files.
 *
 * @param config - The config object.
 * @param manifest - The Snap manifest object.
 * @returns An array of allowed paths.
 */
export declare function getAllowedPaths(config: ProcessedConfig, manifest: SnapManifest): string[];
type Middleware = (app: Express) => void;
/**
 * Get a static server for development purposes.
 *
 * Note: We're intentionally not using `webpack-dev-server` here because it
 * adds a lot of extra stuff to the output that we don't need, and it's
 * difficult to customize.
 *
 * @param config - The config object.
 * @param middleware - An array of middleware functions to run before serving
 * the static files.
 * @returns An object with a `listen` method that returns a promise that
 * resolves when the server is listening.
 */
export declare function getServer(config: ProcessedConfig, middleware?: Middleware[]): {
    listen: (port?: number) => Promise<{
        port: number;
        server: Server;
        close: () => Promise<void>;
    }>;
};
export {};
//# sourceMappingURL=server.d.cts.map